/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 32

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg;
typedef struct tySequence__s12F9c4cKfaapm8VzG9a1flQ tySequence__s12F9c4cKfaapm8VzG9a1flQ;
typedef struct tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ;
typedef struct tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ;
typedef struct tySequence__Ih0V9cYug0VPJyBBGvgEH7Q tySequence__Ih0V9cYug0VPJyBBGvgEH7Q;
typedef struct tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw;
typedef struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyTuple__8jHm6IGDGecciKpp2bTNxA tyTuple__8jHm6IGDGecciKpp2bTNxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;

/* section: NIM_merge_TYPES */
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg {
tySequence__s12F9c4cKfaapm8VzG9a1flQ* data;
NI counter;
};
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg {
  RootObj Sup;
NI bufpos;
NimStringDesc* buf;
tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* input;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars;
};
typedef NU8 tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw;
typedef NU8 tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA;
typedef NU8 tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew;
struct tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ {
  tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg Sup;
NimStringDesc* a;
tyEnum_TokKind__Q9c4KaNqJU4PbXaGht0C7iw tok;
tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA kind;
tyEnum_JsonError__G9cw5MrJXJrcpID5JXaplew err;
tySequence__Ih0V9cYug0VPJyBBGvgEH7Q* state;
NimStringDesc* filename;
NIM_BOOL rawStringLiterals;
};
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef N_NIMCALL_PTR(void, tyProc__JQrsH08b4uPTH9cyFPlVOZg) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__9bmhFrLahRsL2hltfRDVtlQ) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s);
typedef N_NIMCALL_PTR(void, tyProc__3svSoGIUJIsHkaBL7q4DAQ) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s, NI pos);
typedef N_NIMCALL_PTR(NI, tyProc__xflqkf2D1uVClg70czEDHA) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s);
typedef N_NIMCALL_PTR(NI, tyProc__c9c0f59ak4YGQ6neEym8LPKw) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s, NimStringDesc** buffer, tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA slice);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7jFfqMk9ajToCz6Hv9atCA4A) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s, NimStringDesc** line);
typedef N_NIMCALL_PTR(NI, tyProc__2VVzVL9bOnKhj1eZKkf9cEuA) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s, void* buffer, NI bufLen);
typedef N_NIMCALL_PTR(void, tyProc__ki6p1QyfOkJLQJ9aw5NI0AQ) (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* s, void* buffer, NI bufLen);
struct tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ {
  RootObj Sup;
tyProc__JQrsH08b4uPTH9cyFPlVOZg closeImpl;
tyProc__9bmhFrLahRsL2hltfRDVtlQ atEndImpl;
tyProc__3svSoGIUJIsHkaBL7q4DAQ setPositionImpl;
tyProc__xflqkf2D1uVClg70czEDHA getPositionImpl;
tyProc__c9c0f59ak4YGQ6neEym8LPKw readDataStrImpl;
tyProc__7jFfqMk9ajToCz6Hv9atCA4A readLineImpl;
tyProc__2VVzVL9bOnKhj1eZKkf9cEuA readDataImpl;
tyProc__2VVzVL9bOnKhj1eZKkf9cEuA peekDataImpl;
tyProc__ki6p1QyfOkJLQJ9aw5NI0AQ writeDataImpl;
tyProc__JQrsH08b4uPTH9cyFPlVOZg flushImpl;
};
struct tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw {
  tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ Sup;
NimStringDesc* data;
NI pos;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyTuple__8jHm6IGDGecciKpp2bTNxA {
NI Field0;
NI64 Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
typedef NU8 tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ;
struct tyObject_HSlice__EE5dzjqoOrHT6HJhIPXAvA {
NI a;
NI b;
};
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__s12F9c4cKfaapm8VzG9a1flQ {
  TGenericSeq Sup;
  tyTuple__8jHm6IGDGecciKpp2bTNxA data[SEQ_DECL_SIZE];
};
struct tySequence__Ih0V9cYug0VPJyBBGvgEH7Q {
  TGenericSeq Sup;
  tyEnum_ParserState__Na0rM2Zdr3RpxeNeXbvLrQ data[SEQ_DECL_SIZE];
};
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initTable__YTsZ11U9aeIqqeJoGkYFEXQ)(NI initialSize, tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg* Result);
N_LIB_PRIVATE N_NIMCALL(void, open__caSf5pJv2JnMMpxc9bAhdpA)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my, tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* input, NimStringDesc* filename, NIM_BOOL rawStringLiterals);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw*, newStringStream__9aLRtgEYeRMrZKrObtoOslQ)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, next__FPdQ9beZqb3bJ7eVHJww6Qg)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, loadAny__Kcfe39caBC5uVT250dKogGQ)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg* tab, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
static N_INLINE(tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA, kind__4ctGAM18bpGmdbeESXpEMAparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, NimStringDesc* msg) __attribute__((noreturn));
static N_INLINE(NimStringDesc*, str__0rP2wCdbpnXyQhtQ7AnWTwparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
static N_INLINE(NI64, getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NI64, nsuParseBiggestInt)(NimStringDesc* s);
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNode__PMZ27S9ai4FB3gXOMDXvwsQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, elemType__PfgI9ap7WOnsRfFV4znQ27w_2)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqRC1)(TNimType* typ, NI len);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getOrDefault__NuV0kwmS6NPkSg4nGTYxGQ)(tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg t, NI64 key);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimInt64ToStr)(NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___OtPEflpH4zlxCllppdpU2g)(tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg* t, NI64 key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newStrNode__zLcHGdlEbBYFtoCoan9agkg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NimStringDesc* strVal);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFloatNode__FUOXigLcQdNOaWKUo0hkTg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NF floatVal);
static N_INLINE(NF, getFloat__Ne6IckEIGsEYNLHqT2VmQQparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(NF, nsuParseFloat)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
static N_INLINE(void, close__8dle9apIE9cTJGDlKOnqgjgAparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my);
N_LIB_PRIVATE N_NIMCALL(void, close__m9bpQUVeRkyuyv4zAGVgY9bw_3)(tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* L);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, storeAny__l7I4lFY1gRcPW76EbMBfZA)(NimStringDesc** s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* stored, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimBoolToStr)(NIM_BOOL x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeJson__NGTWHwdUy0ADNv9alK3ECRA)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimCharToStr)(NIM_CHAR x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipColon__UPSW0jLTX5qJL51YMUAHgw_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(void, storeObj__oVnZagNd09a2HaQ033USNUQ)(NimStringDesc** s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* stored, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getField__vtwh7CEP5nsVSehDp7nt6w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI position);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
static N_INLINE(NI, ptrToInt__mwRK0r64EAmuGSfMTsaPsgvmmarshal)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimFloatToStr)(NF f);

/* section: NIM_merge_DATA */
extern TNimType NTI__KWIQnzXEOUqdWsnCUL9atyQ_;
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_2, "unknown file", 12);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_3, "\'true\' or \'false\' expected for a bool", 37);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_4, "string of length 1 expected for a char", 38);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_5, "string expected for an enum", 27);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_6, "\'[\' expected for an array", 25);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_7, "\']\' end of array expected", 25);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_8, "\'[\' expected for a seq", 22);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_9, "\'{\' expected for an object", 26);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_10, "string expected for a field name", 32);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_11, "too many fields to tuple type ", 30);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_12, "\'}\' end of object expected", 26);
extern TNimType NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_;
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_13, "unknown field for object of type ", 33);
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_14, "\'[\' expected for a set", 22);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_15, "cannot load object with address ", 32);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_16, "index for ref type expected", 27);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_17, "\']\' end of ref-address pair expected", 36);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_18, "int for pointer type expected", 29);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_19, "string expected", 15);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_20, "int expected", 12);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_21, "float expected", 14);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_22, "cannot marshal at compile-time ", 31);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_24, "/home/runner/work/nightlies/nightlies/nim/compiler/vmmarshal.ni"
"m", 64);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__eBu3XSE68i5yQmrMcuBiww_23 = {((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_24),
((NI) 281),
((NI) 18)}
;
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_25, "null", 4);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_26, "[", 1);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_27, ", ", 2);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_28, "]", 1);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_29, "{", 1);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_30, "\"Field", 6);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_31, "\": ", 3);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_32, "}", 1);
STRING_LITERAL(TM__eBu3XSE68i5yQmrMcuBiww_33, ": ", 2);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__eBu3XSE68i5yQmrMcuBiww_34 = {((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_24),
((NI) 130),
((NI) 18)}
;

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(void, nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__JE6t4x7Z3v2iVz27Nx0MRAmemory(p, ((int) 0), size);
}
static N_INLINE(tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA, kind__4ctGAM18bpGmdbeESXpEMAparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA result;
{	result = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
	result = (*my).kind;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringDesc*, str__0rP2wCdbpnXyQhtQ7AnWTwparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NimStringDesc* result;
{	result = (NimStringDesc*)0;
	result = copyString((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI64, getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NI64 result;
{	result = (NI64)0;
	result = nsuParseBiggestInt((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__P89cqdlERShb9alU3iC0yj8w_2ast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	result = (NI)0;
	{
		if (!((*n).kind >= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 0) && (*n).kind <= ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA3_;
		result = ((NI) 0);
	}
	goto LA1_;
	LA3_: ;
	{
		result = len__P89cqdlERShb9alU3iC0yj8wast(n);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__Bj9c9cm9cBM9coLsuNsT5BvZ9awsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__5mJADrRYkP3r9auuiuDZN9cQast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n).sons ? (*n).sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__M04YC71iJg1N7gBF3HZTngsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__M04YC71iJg1N7gBF3HZTngsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T1_;
	T1_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(p);
	decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T1_);
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(NF, getFloat__Ne6IckEIGsEYNLHqT2VmQQparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	NF result;
{	result = (NF)0;
	result = nsuParseFloat((*my).a);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, loadAny__Kcfe39caBC5uVT250dKogGQ)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* p, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg* tab, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0):
	{
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T3_;
		T3_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
		T3_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
		switch (T3_) {
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 6):
		{
			result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
		}
		break;
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 5):
		{
			result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(1));
		}
		break;
		default:
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_3));
		}
		break;
		}
		next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T10_;
			NimStringDesc* x;
			T10_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T10_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T10_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 2))) goto LA11_;
			x = str__0rP2wCdbpnXyQhtQ7AnWTwparsejson((&(*p)));
			{
				if (!((x ? x->Sup.len : 0) == ((NI) 1))) goto LA15_;
				result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) (((NU8)(x->data[((NI) 0)])))));
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
				goto BeforeRet_;
			}
			LA15_: ;
		}
		goto LA8_;
		LA11_: ;
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T18_;
			NI64 T21_;
			T18_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T18_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T18_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 3))) goto LA19_;
			T21_ = (NI64)0;
			T21_ = getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson((&(*p)));
			result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), T21_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			goto BeforeRet_;
		}
		goto LA8_;
		LA19_: ;
		LA8_: ;
		raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_4));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T25_;
			T25_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T25_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T25_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 2))) goto LA26_;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
				e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				{
					NI i;
					NI colontmp_;
					NI i_2;
					i = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*t).n);
					i_2 = ((NI) 0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA31;
							i = i_2;
							e = (*(*t).n)._kind_6.sons->data[i];
							{
								NimStringDesc* T34_;
								T34_ = (NimStringDesc*)0;
								T34_ = str__0rP2wCdbpnXyQhtQ7AnWTwparsejson((&(*p)));
								if (!eqStrings((*(*(*e)._kind_4.sym).name).s, T34_)) goto LA35_;
								result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), ((NI64) ((*(*e)._kind_4.sym).position)));
								next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
								goto BeforeRet_;
							}
							LA35_: ;
							i_2 += ((NI) 1);
						} LA31: ;
					}
				}
			}
		}
		LA26_: ;
		raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_5));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T40_;
			T40_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T40_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!!((T40_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10)))) goto LA41_;
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_6));
		}
		LA41_: ;
		next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
		{
			while (1) {
				NIM_BOOL T45_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T46_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T48_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T49_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T50_;
				T45_ = (NIM_BOOL)0;
				T46_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T46_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T45_ = !((T46_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11)));
				if (!(T45_)) goto LA47_;
				T48_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T48_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T45_ = !((T48_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1)));
				LA47_: ;
				if (!T45_) goto LA44;
				T49_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T49_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(t);
				T50_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T50_ = loadAny__Kcfe39caBC5uVT250dKogGQ(p, T49_, tab, cache, conf);
				add__P8dDSotTW25BkfbyspojGg(result, T50_);
			} LA44: ;
		}
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T53_;
			T53_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T53_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T53_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11))) goto LA54_;
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		goto LA51_;
		LA54_: ;
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_7));
		}
		LA51_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T58_;
		T58_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
		T58_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
		switch (T58_) {
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 7):
		{
			result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		break;
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10):
		{
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
			{
				while (1) {
					NIM_BOOL T63_;
					tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T64_;
					tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T66_;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T67_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T68_;
					T63_ = (NIM_BOOL)0;
					T64_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
					T64_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
					T63_ = !((T64_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11)));
					if (!(T63_)) goto LA65_;
					T66_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
					T66_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
					T63_ = !((T66_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1)));
					LA65_: ;
					if (!T63_) goto LA62;
					T67_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					T67_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(t);
					T68_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T68_ = loadAny__Kcfe39caBC5uVT250dKogGQ(p, T67_, tab, cache, conf);
					add__P8dDSotTW25BkfbyspojGg(result, T68_);
				} LA62: ;
			}
			{
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T71_;
				T71_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T71_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				if (!(T71_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11))) goto LA72_;
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			}
			goto LA69_;
			LA72_: ;
			{
				raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) NIM_NIL));
			}
			LA69_: ;
		}
		break;
		default:
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_8));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		NI i_3;
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T79_;
			T79_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T79_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!!((T79_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8)))) goto LA80_;
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_9));
		}
		LA80_: ;
		next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 160));
		i_3 = ((NI) 0);
		{
			while (1) {
				NIM_BOOL T84_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T85_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T87_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T100_;
				T84_ = (NIM_BOOL)0;
				T85_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T85_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T84_ = !((T85_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9)));
				if (!(T84_)) goto LA86_;
				T87_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T87_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T84_ = !((T87_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1)));
				LA86_: ;
				if (!T84_) goto LA83;
				{
					tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T90_;
					T90_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
					T90_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
					if (!!((T90_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 2)))) goto LA91_;
					raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_10));
				}
				LA91_: ;
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
				{
					NI T95_;
					NimStringDesc* T98_;
					NimStringDesc* T99_;
					T95_ = (NI)0;
					T95_ = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
					if (!(T95_ <= i_3)) goto LA96_;
					T98_ = (NimStringDesc*)0;
					T99_ = (NimStringDesc*)0;
					T99_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T98_ = rawNewString((T99_ ? T99_->Sup.len : 0) + 30);
appendString(T98_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_11));
appendString(T98_, T99_);
					raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), T98_);
				}
				LA96_: ;
				T100_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T100_ = loadAny__Kcfe39caBC5uVT250dKogGQ(p, (*t).sons->data[i_3], tab, cache, conf);
				add__P8dDSotTW25BkfbyspojGg(result, T100_);
				i_3 += ((NI) 1);
			} LA83: ;
		}
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T103_;
			T103_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T103_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T103_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9))) goto LA104_;
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		goto LA101_;
		LA104_: ;
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_12));
		}
		LA101_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T110_;
			T110_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T110_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!!((T110_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 8)))) goto LA111_;
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_9));
		}
		LA111_: ;
		next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38));
		if ((*result)._kind_6.sons) { nimGCunrefNoCycle((*result)._kind_6.sons); (*result)._kind_6.sons = NIM_NIL; }
		(*result)._kind_6.sons = (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) newSeqRC1((&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), 1);
		asgnRef((void**) (&(*result)._kind_6.sons->data[0]), newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1)));
		{
			while (1) {
				NIM_BOOL T115_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T116_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T118_;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
				NimStringDesc* T124_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
				NI pos;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldNode;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T136_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T137_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T138_;
				T115_ = (NIM_BOOL)0;
				T116_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T116_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T115_ = !((T116_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9)));
				if (!(T115_)) goto LA117_;
				T118_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T118_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T115_ = !((T118_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1)));
				LA117_: ;
				if (!T115_) goto LA114;
				{
					tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T121_;
					T121_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
					T121_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
					if (!!((T121_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 2)))) goto LA122_;
					raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_10));
				}
				LA122_: ;
				T124_ = (NimStringDesc*)0;
				T124_ = str__0rP2wCdbpnXyQhtQ7AnWTwparsejson((&(*p)));
				ident = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, T124_);
				field = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*t).n, ident);
				{
					NimStringDesc* T129_;
					NimStringDesc* T130_;
					if (!(field == 0)) goto LA127_;
					T129_ = (NimStringDesc*)0;
					T130_ = (NimStringDesc*)0;
					T130_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
					T129_ = rawNewString((T130_ ? T130_->Sup.len : 0) + 33);
appendString(T129_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_13));
appendString(T129_, T130_);
					raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), T129_);
				}
				LA127_: ;
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
				pos = (NI)((*field).position + ((NI) 1));
				{
					NI T133_;
					T133_ = (NI)0;
					T133_ = len__P89cqdlERShb9alU3iC0yj8wast(result);
					if (!(T133_ <= pos)) goto LA134_;
					asgnRef((void**) (&(*result)._kind_6.sons), (tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ*) setLengthSeqV2(&((*result)._kind_6.sons)->Sup, (&NTI__ehmV9bTklH2Gt9cXHV9c0HLeQ_), ((NI) ((NI)(pos + ((NI) 1))))));
				}
				LA134_: ;
				fieldNode = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34));
				T136_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T136_ = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), ident, ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL), unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, 0);
				T137_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T137_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T136_);
				add__P8dDSotTW25BkfbyspojGg(fieldNode, T137_);
				T138_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T138_ = loadAny__Kcfe39caBC5uVT250dKogGQ(p, (*field).typ, tab, cache, conf);
				add__P8dDSotTW25BkfbyspojGg(fieldNode, T138_);
				asgnRef((void**) (&(*result)._kind_6.sons->data[pos]), fieldNode);
			} LA114: ;
		}
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T141_;
			T141_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T141_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T141_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 9))) goto LA142_;
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		goto LA139_;
		LA142_: ;
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_12));
		}
		LA139_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T148_;
			T148_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T148_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!!((T148_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10)))) goto LA149_;
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_14));
		}
		LA149_: ;
		next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 39));
		{
			while (1) {
				NIM_BOOL T153_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T154_;
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T156_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T157_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T158_;
				T153_ = (NIM_BOOL)0;
				T154_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T154_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T153_ = !((T154_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11)));
				if (!(T153_)) goto LA155_;
				T156_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T156_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				T153_ = !((T156_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 1)));
				LA155_: ;
				if (!T153_) goto LA152;
				T157_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T157_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
				T158_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T158_ = loadAny__Kcfe39caBC5uVT250dKogGQ(p, T157_, tab, cache, conf);
				add__P8dDSotTW25BkfbyspojGg(result, T158_);
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			} LA152: ;
		}
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T161_;
			T161_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T161_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T161_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11))) goto LA162_;
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		goto LA159_;
		LA162_: ;
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_7));
		}
		LA159_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T166_;
		T166_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
		T166_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
		switch (T166_) {
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 7):
		{
			result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		break;
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 3):
		{
			NI64 T169_;
			T169_ = (NI64)0;
			T169_ = getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson((&(*p)));
			result = getOrDefault__NuV0kwmS6NPkSg4nGTYxGQ((*tab), T169_);
			{
				NimStringDesc* T174_;
				NI64 T175_;
				NimStringDesc* T176_;
				if (!(result == 0)) goto LA172_;
				T174_ = (NimStringDesc*)0;
				T175_ = (NI64)0;
				T175_ = getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson((&(*p)));
				T176_ = (NimStringDesc*)0;
				T176_ = nimInt64ToStr(T175_);
				T174_ = rawNewString((T176_ ? T176_->Sup.len : 0) + 32);
appendString(T174_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_15));
appendString(T174_, T176_);
				raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), T174_);
			}
			LA172_: ;
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		break;
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 10):
		{
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			{
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T180_;
				NI64 idx;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T183_;
				T180_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T180_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				if (!(T180_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 3))) goto LA181_;
				idx = getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson((&(*p)));
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
				T183_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T183_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
				result = loadAny__Kcfe39caBC5uVT250dKogGQ(p, T183_, tab, cache, conf);
				X5BX5Deq___OtPEflpH4zlxCllppdpU2g(tab, idx, result);
			}
			goto LA178_;
			LA181_: ;
			{
				raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_16));
			}
			LA178_: ;
			{
				tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T187_;
				T187_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
				T187_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
				if (!(T187_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 11))) goto LA188_;
				next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			}
			goto LA185_;
			LA188_: ;
			{
				raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_17));
			}
			LA185_: ;
		}
		break;
		default:
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_18));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T193_;
		T193_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
		T193_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
		switch (T193_) {
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 7):
		{
			result = newNode__PMZ27S9ai4FB3gXOMDXvwsQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		break;
		case ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 2):
		{
			NimStringDesc* T196_;
			T196_ = (NimStringDesc*)0;
			T196_ = str__0rP2wCdbpnXyQhtQ7AnWTwparsejson((&(*p)));
			result = newStrNode__zLcHGdlEbBYFtoCoan9agkg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 20), T196_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
		}
		break;
		default:
		{
			raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_19));
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T201_;
			NI64 T204_;
			T201_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T201_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T201_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 3))) goto LA202_;
			T204_ = (NI64)0;
			T204_ = getInt__xts1yUqLRDbf9cxU9bxvopNgparsejson((&(*p)));
			result = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), T204_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			goto BeforeRet_;
		}
		LA202_: ;
		raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_20));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		{
			tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA T208_;
			NF T211_;
			T208_ = (tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA)0;
			T208_ = kind__4ctGAM18bpGmdbeESXpEMAparsejson((&(*p)));
			if (!(T208_ == ((tyEnum_JsonEventKind__0zjE9c54eTrq224F5wMcaFA) 4))) goto LA209_;
			T211_ = (NF)0;
			T211_ = getFloat__Ne6IckEIGsEYNLHqT2VmQQparsejson((&(*p)));
			result = newFloatNode__FUOXigLcQdNOaWKUo0hkTg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 16), T211_);
			next__FPdQ9beZqb3bJ7eVHJww6Qg(p);
			goto BeforeRet_;
		}
		LA209_: ;
		raiseParseErr__VeBRAkMdST9cPQW1Rqk8vwA((&(*p)), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_21));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T213_;
		T213_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T213_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		result = loadAny__Kcfe39caBC5uVT250dKogGQ(p, T213_, tab, cache, conf);
	}
	break;
	default:
	{
		NimStringDesc* T215_;
		NimStringDesc* T216_;
		T215_ = (NimStringDesc*)0;
		T216_ = (NimStringDesc*)0;
		T216_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T215_ = rawNewString((T216_ ? T216_->Sup.len : 0) + 31);
appendString(T215_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_22));
appendString(T215_, T216_);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, T215_, TM__eBu3XSE68i5yQmrMcuBiww_23);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, close__8dle9apIE9cTJGDlKOnqgjgAparsejson)(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ* my) {
	tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg* T1_;
	T1_ = (tyObject_BaseLexer__MAw8rJZtJ279bVV3TWMtXSg*)0;
	T1_ = &my->Sup;
	close__m9bpQUVeRkyuyv4zAGVgY9bw_3(T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, loadAny__Sr5ibxUUgGhmgltd4r9cYpg)(NimStringDesc* s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg tab;
	tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ p;
	tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw* T1_;
	tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&tab), sizeof(tyObject_Table__7O9bs4LORhqcR0JGh7d1MDg));
	initTable__YTsZ11U9aeIqqeJoGkYFEXQ(((NI) 32), (&tab));
	nimZeroMem((void*)(&p), sizeof(tyObject_JsonParser__KWIQnzXEOUqdWsnCUL9atyQ));
	p.Sup.Sup.m_type = (&NTI__KWIQnzXEOUqdWsnCUL9atyQ_);
	T1_ = (tyObject_StringStreamObj__Olau5FPRehZBBEB77FHnfw*)0;
	T1_ = newStringStream__9aLRtgEYeRMrZKrObtoOslQ(s);
	T2_ = (tyObject_StreamObj__THYguAi9bSgidczZ3ywEIMQ*)0;
	T2_ = &T1_->Sup;
	open__caSf5pJv2JnMMpxc9bAhdpA((&p), T2_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_2), NIM_FALSE);
	next__FPdQ9beZqb3bJ7eVHJww6Qg((&p));
	result = loadAny__Kcfe39caBC5uVT250dKogGQ((&p), t, (&tab), cache, conf);
	close__8dle9apIE9cTJGDlKOnqgjgAparsejson((&p));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getField__vtwh7CEP5nsVSehDp7nt6w)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, NI position) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
{	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 138):
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i = i_2;
					result = getField__vtwh7CEP5nsVSehDp7nt6w((*n)._kind_6.sons->data[i], position);
					{
						if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA7_;
						goto BeforeRet_;
					}
					LA7_: ;
					i_2 += ((NI) 1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 139):
	{
		result = getField__vtwh7CEP5nsVSehDp7nt6w((*n)._kind_6.sons->data[((NI) 0)], position);
		{
			if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA12_;
			goto BeforeRet_;
		}
		LA12_: ;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_4 = ((NI) 1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA16;
					i_3 = i_4;
					switch ((*(*n)._kind_6.sons->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 85):
					case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 88):
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
						T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T18_ = lastSon__UPSW0jLTX5qJL51YMUAHgw((*n)._kind_6.sons->data[i_3]);
						result = getField__vtwh7CEP5nsVSehDp7nt6w(T18_, position);
						{
							if (!!((result == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA21_;
							goto BeforeRet_;
						}
						LA21_: ;
					}
					break;
					default:
					{
					}
					break;
					}
					i_4 += ((NI) 1);
				} LA16: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		{
			if (!((*(*n)._kind_4.sym).position == position)) goto LA27_;
			result = (*n)._kind_4.sym;
		}
		LA27_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeObj__oVnZagNd09a2HaQ033USNUQ)(NimStringDesc** s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* stored, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	NI start;
	start = ((NI) 1);
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(x);
		i_2 = start;
		{
			while (1) {
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* it;
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					if (!(start < i)) goto LA6_;
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
				}
				LA6_: ;
				it = (*x)._kind_6.sons->data[i];
				{
					if (!((*it).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 34))) goto LA10_;
					{
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
						NimStringDesc* T16_;
						if (!((*(*it)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA14_;
						field = (*(*it)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
						T16_ = (NimStringDesc*)0;
						T16_ = escapeJson__NGTWHwdUy0ADNv9alK3ECRA((*(*field).name).s);
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T16_ ? T16_->Sup.len : 0) + 0));
appendString((*s), T16_);
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_33));
						storeAny__l7I4lFY1gRcPW76EbMBfZA(s, (*field).typ, (*it)._kind_6.sons->data[((NI) 1)], stored, conf);
					}
					LA14_: ;
				}
				goto LA8_;
				LA10_: ;
				{
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_2;
					NimStringDesc* T20_;
					if (!!(((*typ).n == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA18_;
					field_2 = getField__vtwh7CEP5nsVSehDp7nt6w((*typ).n, i);
					T20_ = (NimStringDesc*)0;
					T20_ = escapeJson__NGTWHwdUy0ADNv9alK3ECRA((*(*field_2).name).s);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T20_ ? T20_->Sup.len : 0) + 0));
appendString((*s), T20_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_33));
					storeAny__l7I4lFY1gRcPW76EbMBfZA(s, (*field_2).typ, it, stored, conf);
				}
				goto LA8_;
				LA18_: ;
				LA8_: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
static N_INLINE(NI, ptrToInt__mwRK0r64EAmuGSfMTsaPsgvmmarshal)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x) {
	NI result;
	result = (NI)0;
	result = ((NI) (x));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, storeAny__l7I4lFY1gRcPW76EbMBfZA)(NimStringDesc** s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* stored, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	switch ((*t).kind) {
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 0):
	{
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1):
	{
		NimStringDesc* T3_;
		T3_ = (NimStringDesc*)0;
		T3_ = nimBoolToStr(!(((*a)._kind_1.intVal == IL64(0))));
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T3_ ? T3_->Sup.len : 0) + 0));
appendString((*s), T3_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 2):
	{
		NIM_CHAR ch;
		ch = ((NIM_CHAR) ((*a)._kind_1.intVal));
		{
			NimStringDesc* T9_;
			NimStringDesc* T10_;
			if (!((NU8)(ch) < (NU8)(128))) goto LA7_;
			T9_ = (NimStringDesc*)0;
			T9_ = nimCharToStr(ch);
			T10_ = (NimStringDesc*)0;
			T10_ = escapeJson__NGTWHwdUy0ADNv9alK3ECRA(T9_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T10_ ? T10_->Sup.len : 0) + 0));
appendString((*s), T10_);
		}
		goto LA5_;
		LA7_: ;
		{
			NimStringDesc* T12_;
			T12_ = (NimStringDesc*)0;
			T12_ = nimIntToStr(((NI) (((NU8)(ch)))));
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T12_ ? T12_->Sup.len : 0) + 0));
appendString((*s), T12_);
		}
		LA5_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 16):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24):
	{
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*t).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 24));
			if (!(T16_)) goto LA17_;
			T16_ = ((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			LA17_: ;
			if (!T16_) goto LA18_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_25));
		}
		goto LA14_;
		LA18_: ;
		{
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_26));
			{
				NI i;
				NI colontmp_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(a);
				i_2 = ((NI) 0);
				{
					while (1) {
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T28_;
						if (!(i_2 < colontmp_)) goto LA23;
						i = i_2;
						{
							if (!(((NI) 0) < i)) goto LA26_;
							unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
						}
						LA26_: ;
						T28_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T28_ = elemType__PfgI9ap7WOnsRfFV4znQ27w_2(t);
						storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T28_, (*a)._kind_6.sons->data[i], stored, conf);
						i_2 += ((NI) 1);
					} LA23: ;
				}
			}
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_28));
		}
		LA14_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 18):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_29));
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__5mJADrRYkP3r9auuiuDZN9cQast(t);
			i_4 = ((NI) 0);
			{
				while (1) {
					NimStringDesc* T37_;
					NimStringDesc* T38_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T39_;
					if (!(i_4 < colontmp__2)) goto LA32;
					i_3 = i_4;
					{
						if (!(((NI) 0) < i_3)) goto LA35_;
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
					}
					LA35_: ;
					T37_ = (NimStringDesc*)0;
					T38_ = (NimStringDesc*)0;
					T38_ = nimIntToStr(i_3);
					T37_ = rawNewString((T38_ ? T38_->Sup.len : 0) + 6);
appendString(T37_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_30));
appendString(T37_, T38_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T37_ ? T37_->Sup.len : 0) + 0));
appendString((*s), T37_);
					unsureAsgnRef((void**) (&(*s)), resizeString((*s), 3));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_31));
					T39_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T39_ = skipColon__UPSW0jLTX5qJL51YMUAHgw_3((*a)._kind_6.sons->data[i_3]);
					storeAny__l7I4lFY1gRcPW76EbMBfZA(s, (*t).sons->data[i_3], T39_, stored, conf);
					i_4 += ((NI) 1);
				} LA32: ;
			}
		}
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_32));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 17):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_29));
		storeObj__oVnZagNd09a2HaQ033USNUQ(s, t, a, stored, conf);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_32));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 19):
	{
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_26));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__P89cqdlERShb9alU3iC0yj8wast(a);
			i_6 = ((NI) 0);
			{
				while (1) {
					if (!(i_6 < colontmp__3)) goto LA44;
					i_5 = i_6;
					{
						if (!(((NI) 0) < i_5)) goto LA47_;
						unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
					}
					LA47_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T53_;
						if (!((*(*a)._kind_6.sons->data[i_5]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44))) goto LA51_;
						x = copyNode__Dsjo9bte8vGxzhtcSrsTyiQ_2((*(*a)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 0)]);
						T53_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T53_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
						storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T53_, x, stored, conf);
						{
							while (1) {
								tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T56_;
								if (!((NI64)((*x)._kind_1.intVal + IL64(1)) <= (*(*(*a)._kind_6.sons->data[i_5])._kind_6.sons->data[((NI) 1)])._kind_1.intVal)) goto LA55;
								unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
								T56_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
								T56_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
								storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T56_, x, stored, conf);
								(*x)._kind_1.intVal += ((NI) 1);
							} LA55: ;
						}
					}
					goto LA49_;
					LA51_: ;
					{
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T58_;
						T58_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
						T58_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
						storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T58_, (*a)._kind_6.sons->data[i_5], stored, conf);
					}
					LA49_: ;
					i_6 += ((NI) 1);
				} LA44: ;
			}
		}
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_28));
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 4):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 46):
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T60_;
		T60_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T60_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
		storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T60_, a, stored, conf);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 14):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* e;
			e = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__P89cqdlERShb9alU3iC0yj8w_2ast((*t).n);
				i_8 = ((NI) 0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA65;
						i_7 = i_8;
						e = (*(*t).n)._kind_6.sons->data[i_7];
						{
							NimStringDesc* T70_;
							if (!(((NI64) ((*(*e)._kind_4.sym).position)) == (*a)._kind_1.intVal)) goto LA68_;
							T70_ = (NimStringDesc*)0;
							T70_ = escapeJson__NGTWHwdUy0ADNv9alK3ECRA((*(*(*e)._kind_4.sym).name).s);
							unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T70_ ? T70_->Sup.len : 0) + 0));
appendString((*s), T70_);
							goto LA62;
						}
						LA68_: ;
						i_8 += ((NI) 1);
					} LA65: ;
				}
			}
		} LA62: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22):
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x_2;
		x_2 = a;
		{
			NIM_BOOL T74_;
			T74_ = (NIM_BOOL)0;
			T74_ = (x_2 == 0);
			if (T74_) goto LA75_;
			T74_ = ((*x_2).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23));
			LA75_: ;
			if (!T74_) goto LA76_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_25));
		}
		goto LA72_;
		LA76_: ;
		{
			NI T79_;
			NIM_BOOL T80_;
			NI T83_;
			NimStringDesc* T84_;
			T79_ = (NI)0;
			T79_ = ptrToInt__mwRK0r64EAmuGSfMTsaPsgvmmarshal(x_2);
			T80_ = (NIM_BOOL)0;
			T80_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg(stored, T79_);
			if (!T80_) goto LA81_;
			T83_ = (NI)0;
			T83_ = ptrToInt__mwRK0r64EAmuGSfMTsaPsgvmmarshal(x_2);
			T84_ = (NimStringDesc*)0;
			T84_ = nimIntToStr(T83_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T84_ ? T84_->Sup.len : 0) + 0));
appendString((*s), T84_);
		}
		goto LA72_;
		LA81_: ;
		{
			NI T86_;
			NimStringDesc* T87_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T88_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_26));
			T86_ = (NI)0;
			T86_ = ptrToInt__mwRK0r64EAmuGSfMTsaPsgvmmarshal(x_2);
			T87_ = (NimStringDesc*)0;
			T87_ = nimIntToStr(T86_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T87_ ? T87_->Sup.len : 0) + 0));
appendString((*s), T87_);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 2));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_27));
			T88_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T88_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t);
			storeAny__l7I4lFY1gRcPW76EbMBfZA(s, T88_, a, stored, conf);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 1));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_28));
		}
		LA72_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 29):
	{
		{
			if (!((*a).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA92_;
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), 4));
appendString((*s), ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_25));
		}
		goto LA90_;
		LA92_: ;
		{
			NimStringDesc* T95_;
			T95_ = (NimStringDesc*)0;
			T95_ = escapeJson__NGTWHwdUy0ADNv9alK3ECRA((*a)._kind_3.strVal);
			unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T95_ ? T95_->Sup.len : 0) + 0));
appendString((*s), T95_);
		}
		LA90_: ;
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 35):
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 40) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 44):
	{
		NimStringDesc* T97_;
		T97_ = (NimStringDesc*)0;
		T97_ = nimInt64ToStr((*a)._kind_1.intVal);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T97_ ? T97_->Sup.len : 0) + 0));
appendString((*s), T97_);
	}
	break;
	case ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 36) ... ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 39):
	{
		NimStringDesc* T99_;
		T99_ = (NimStringDesc*)0;
		T99_ = nimFloatToStr((*a)._kind_2.floatVal);
		unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T99_ ? T99_->Sup.len : 0) + 0));
appendString((*s), T99_);
	}
	break;
	default:
	{
		NimStringDesc* T101_;
		NimStringDesc* T102_;
		T101_ = (NimStringDesc*)0;
		T102_ = (NimStringDesc*)0;
		T102_ = typeToString__QlvraUan7WbHowhAbvDvdA(t, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T101_ = rawNewString((T102_ ? T102_->Sup.len : 0) + 31);
appendString(T101_, ((NimStringDesc*) &TM__eBu3XSE68i5yQmrMcuBiww_22));
appendString(T101_, T102_);
		internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw(conf, (*a).info, T101_, TM__eBu3XSE68i5yQmrMcuBiww_34);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, storeAny__OIEM18oCrQXxJj2UzbHuPA)(NimStringDesc** s, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf) {
	tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg stored;
	nimZeroMem((void*)(&stored), sizeof(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&stored));
	storeAny__l7I4lFY1gRcPW76EbMBfZA(s, t, a, (&stored), conf);
}
